.htaccess
COPYRIGHT.md
HELP_US.txt
LICENSE.md
README.md
README2.txt
WebsiteChecker.php
_install
_protected
_repository
composer.json
data
favicon.ico
humans.txt
index.php
installation-instructions-(start-here).txt
robots.txt
sample.htaccess
service-worker.js
static
templates
_constants.php